@@ -1,12 +1,13 @@
 import re
 
 
-class Side_Step:
+class SideStep:
 
     def __init__(self, step):
         self.step = step
+        self.pipeline_id = pipeline_id
 
-        if spark.conf.get("pipelines.id", None):
+        if self.pipeline_id:
             exec(self.step, globals())
         else:
             self.side_step = self.dlt_removal()
